﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

using DSA.Models;

namespace DSA.UserControls {
    /// <summary>
    /// Interaction logic for USBasicDatas.xaml
    /// </summary>
    public partial class USBasicDatas : UserControl {

        private ModelBasicDatas basdata = null;
        private ModelProject project = null;

        private IUserControls parent = null;

        public USBasicDatas(IUserControls parent, ModelProject project, ModelBasicDatas basdata) {
            InitializeComponent();
            this.parent = parent;
            this.project = project;
            this.basdata = basdata;

            this.FontSize = MyRegistry.FontSize;
            labelcaption.FontSize = MyRegistry.FontSize + 1;

            setDatas();
            if (parent == null) {
                bnDelete.IsEnabled = false;
                bnCopy.IsEnabled = false;
                bnOk.IsEnabled = false;
                bnEsc.IsEnabled = false;
            }
        }

        private void setComboBox(ComboBox cb, List<ModelDatalist> liste, String item) {            
            foreach (ModelDatalist datalist in liste) {
                cb.Items.Add(datalist.Label);
            }
            int index = 0;
            for (int i=0; i<liste.Count; i++) {
                ModelDatalist datalist = liste[i];                
                if ( datalist.Label.Equals(item) ) {
                    index = i;
                    break;
                }
            }
            cb.SelectedIndex = index;
        }

        // ComboBox und gewählte Inhalte
        private void setDatas() {
            tcaption.Text = basdata.Caption;
            setComboBox(cbspecies, project.speciesListe, basdata.Species);
            setComboBox(cbgender, project.genderListe, basdata.Gender);
            setComboBox(cbeyecolor, project.eyecolorListe, basdata.Eyecolor);
            setComboBox(cbhaircolor, project.haircolorListe, basdata.Haircolor);
            setComboBox(cbbodycolor, project.bodycolorListe, basdata.Bodycolor);
            setComboBox(cbexperiencelevel, project.experienceLevelListe, basdata.Experiencelevel);

            setComboBox(cbsocialstate, project.socialstateListe, basdata.Socialstate);
            setComboBox(cbculture, project.cultureListe, basdata.Culture);
            setComboBox(cbprofession, project.professionListe, basdata.Profession);
            setComboBox(cbtradition, project.traditionListe, basdata.Tradition);

            setComboBox(cbfaith, project.faithListe, basdata.Faith);
            setComboBox(cbanimalsoul, project.animalsoulListe, basdata.Animalsoul);

            tplayname.Text = basdata.Playname;
            tbirthplace.Text = basdata.Birthplace;
            tbirthday.Text = basdata.Birthday;
            tmytitle.Text = basdata.Title;
            tbodyheight.Text = basdata.Bodyheight.ToString("0");
            tbodyweight.Text = basdata.Bodyweight.ToString("0.00");


        }

        private void bnSave_Click(Object sender, RoutedEventArgs e) {
            basdata.Caption = tcaption.Text.Trim();
            basdata.Species = cbspecies.Text;

            basdata.Gender = cbgender.Text;
            basdata.Eyecolor = cbeyecolor.Text;
            basdata.Bodycolor = cbbodycolor.Text;
            basdata.Experiencelevel = cbexperiencelevel.Text;

            basdata.Socialstate = cbsocialstate.Text;
            basdata.Culture = cbculture.Text;
            basdata.Profession = cbprofession.Text;
            basdata.Tradition = cbtradition.Text;



            basdata.Faith = cbfaith.Text;
            basdata.Animalsoul = cbanimalsoul.Text;

            basdata.Playname = tplayname.Text.Trim();
            basdata.Birthplace =tbirthplace.Text;
            basdata.Birthday =tbirthday.Text;
            basdata.Title = tmytitle.Text;
            int bodyheight = 0;
            if (!int.TryParse(tbodyheight.Text, out bodyheight)) {
                Basis.ErrorMsg("Please insert a correct number in the bodyheight", "Error");
                return;
            }
            basdata.Bodyheight = bodyheight;

            decimal bodyweight = 0.0m;
            if (!decimal.TryParse(tbodyweight.Text, out bodyweight)) {
                Basis.ErrorMsg("Please insert a correct number in the bodyweight", "Error");
                return;
            }
            basdata.Bodyweight = bodyweight;
            project.saveBasicDatas2Database();

            parent.clearDockPanel();
        }

        private void bnEsc_Click(Object sender, RoutedEventArgs e) {
            parent.clearDockPanel();
        }

        private void bnDelete_Click(Object sender, RoutedEventArgs e) {
            if (Basis.readNoYes("Do you really want to delete this item?","delete Basic data")) {
                parent.deleteAndclearDockPanel();
            }            
        }

        private void bnCopy_Click(Object sender, RoutedEventArgs e) {
            parent.copyAndclearDockPanel();
        }
    }
}
