﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;


using DSA.Models;
using Microsoft.Win32;
using System.IO;
using System.Diagnostics;
using DSA.ViewsDialog;

namespace DSA.UserControls {
    /// <summary>
    /// Interaction logic for USCreateScript.xaml
    /// </summary>
    public partial class USCreateScript : UserControl {

        private ModelProject project = null;

        private IUserControls parent = null;

        private List<ModelBasicDatas> basicListe = null;
        private List<ModelBackground> bgListe = null;

        public USCreateScript(IUserControls parent, ModelProject project) {
            InitializeComponent();
            this.parent = parent;
            this.project = project;

            this.FontSize = MyRegistry.FontSize;
            labelcaption.FontSize = MyRegistry.FontSize + 1;

            setDatas();
        }

        private void setDatas() {
            tcaption.Text = "Create a game script with the variants";
            basicListe = project.basicListe;
            foreach (ModelBasicDatas basisData in basicListe) {
                cbGrundlagen.Items.Add(basisData.Caption);
            }

            bgListe = project.backgroundListe;
            foreach (ModelBackground bg in bgListe) {
                cbBackgroundHistory.Items.Add(bg.Caption);
            }
        }


        private void bnShowBasic_Click(Object sender, RoutedEventArgs e) {
            if (cbGrundlagen.SelectedIndex>=0) {
                ModelBasicDatas basisData = basicListe[cbGrundlagen.SelectedIndex];
                WShowUserControls dialog = new WShowUserControls();
                USBasicDatas usbasdata = new USBasicDatas(null, project, basisData);
                dialog.panel.Children.Add(usbasdata);
                dialog.Show();
            }
        }

        private void bnShowBackground_Click(Object sender, RoutedEventArgs e) {
            if (cbBackgroundHistory.SelectedIndex >= 0) {
                ModelBackground bg = bgListe[cbBackgroundHistory.SelectedIndex];

                WShowUserControls dialog = new WShowUserControls();
                USBackground usbg = new USBackground(null, project, bg);
                dialog.panel.Children.Add(usbg);
                dialog.Show();

            }
        }

        private void bnSelectFilename_Click(Object sender, RoutedEventArgs e) {
            SaveFileDialog saveFileDialog1 = new SaveFileDialog();
            saveFileDialog1.Filter = "Export-Datei (*.txt)|*.txt|All files (*.*)|*.*";
            saveFileDialog1.FilterIndex = 1;// zählt von 1 !
            saveFileDialog1.DefaultExt = ".txt";
            saveFileDialog1.FileName = "export.txt";
            saveFileDialog1.InitialDirectory = Environment.CurrentDirectory;
            if (saveFileDialog1.ShowDialog() == true) {
                tFilename.Text = saveFileDialog1.FileName;
            }
        }

        private void bnSave_Click(Object sender, RoutedEventArgs e) {
            if (cbGrundlagen.SelectedIndex ==-1) {
                Basis.ErrorMsg("Please select a basic data item", "Info");
                cbGrundlagen.Focus();
                return;
            }
            if (cbBackgroundHistory.SelectedIndex == -1) {
                Basis.ErrorMsg("Please select a background history item", "Info");
                cbBackgroundHistory.Focus();
                return;
            }
            if (tFilename.Text.Trim().Length==0) {
                Basis.ErrorMsg("Please select a filename", "Info");
                bnSelectFilename.Focus();
                return;
            }
            ModelBasicDatas basisData = basicListe[cbGrundlagen.SelectedIndex];
            ModelBackground bg = bgListe[cbBackgroundHistory.SelectedIndex];

            StringBuilder sb = new StringBuilder();
            sb.AppendLine(basisData.Playname);
            sb.AppendLine(basisData.Title);
            sb.AppendLine(basisData.Birthplace);
            sb.AppendLine(basisData.Birthday);
            sb.AppendLine(basisData.Bodyheight.ToString("0"));
            sb.AppendLine(basisData.Bodyweight.ToString("0.00"));
            sb.AppendLine(basisData.Gender);
            sb.AppendLine(basisData.Eyecolor);
            sb.AppendLine(basisData.Haircolor);
            sb.AppendLine(basisData.Bodycolor);
            sb.AppendLine(basisData.Experiencelevel);
            sb.AppendLine(basisData.Species);
            sb.AppendLine(basisData.Socialstate);
            sb.AppendLine(basisData.Culture);
            sb.AppendLine(basisData.Profession);
            sb.AppendLine(basisData.Tradition);
            sb.AppendLine(basisData.Faith);
            sb.AppendLine(basisData.Animalsoul);
            sb.AppendLine(basisData.Advantage);
            sb.AppendLine(basisData.Disadvantage);


            sb.AppendLine(bg.Story.Replace("\r\n"," "));

            try {
                File.WriteAllText(tFilename.Text, sb.ToString());
                Process Prog = new Process();
                Prog.StartInfo.FileName = "Notepad.exe";
                Prog.StartInfo.Arguments = tFilename.Text;
                Prog.Start();
            }
            catch (Exception e1) {
                Basis.ErrorMsg("Error in writing\r\n" + e1.ToString(), "Error");
            }
            parent.clearDockPanel();
        }

        private void bnEsc_Click(Object sender, RoutedEventArgs e) {
            parent.clearDockPanel();
        }
    }
}
